package itdi;

import org.aspectj.org.eclipse.jdt.core.compiler.CharOperation;
import org.aspectj.org.eclipse.jdt.internal.compiler.ast.MarkerAnnotation;
import org.aspectj.org.eclipse.jdt.internal.compiler.ast.QualifiedTypeReference;
import org.aspectj.org.eclipse.jdt.internal.compiler.ast.SingleMemberAnnotation;
import org.aspectj.org.eclipse.jdt.internal.compiler.lookup.AnnotationBinding;
import org.aspectj.org.eclipse.jdt.internal.compiler.lookup.MethodBinding;
import org.aspectj.weaver.AnnotationAJ;
import org.aspectj.weaver.ResolvedMember;
import org.aspectj.weaver.ResolvedType;

public class ITDIUtility {
	static {
		String itdiS = "itdi";
		String annotationS = "annotation";
		String finalS = "Final";
		String introducedS = "Introduced";
		String introducesS = "Introduces";
		String itdiLS = "ITDI";
		String itdi_annotation = itdiS + "." + annotationS + "."; 
		
		itdi = itdiS.toCharArray();
		annotation = annotationS.toCharArray();
		finalA = finalS.toCharArray();
		introduced = introducedS.toCharArray();
		introduces = introducesS.toCharArray();
		itdiA = itdiLS.toCharArray();
		
		itdi_annotation_final = itdi_annotation + finalS;
		itdi_annotation_introduced = itdi_annotation + introducedS;
		itdi_annotation_introduces = itdi_annotation + introducesS;
		itdi_annotation_itdi = itdi_annotation + itdiLS;
	}
	
	private static final char[] itdi, annotation, finalA, introduced, introduces, itdiA;
	private static final String itdi_annotation_introduced, itdi_annotation_introduces, 
			itdi_annotation_itdi, itdi_annotation_final;
	
	public static boolean isIntroduced(ResolvedMember m) {
		return containsAnn(m.getAnnotations(), itdi_annotation_introduced);
	}
	
	public static boolean introduces(ResolvedType aspectType, ResolvedType itdi) {
		String targetITDIName = itdi.getName();
		
		for (String itdiName: getIntroducesITDIs(aspectType)) {
			if (targetITDIName.equals(itdiName)) {
				return true;
			}
		}
		
		return false;
	}
	
	public static String[] getIntroducesITDIs(ResolvedType aspectType) {
		AnnotationAJ[] annotations = aspectType.getAnnotations();
		
		if (annotations != null) {
			for (AnnotationAJ ann: aspectType.getAnnotations()) {
				if (ann.getTypeName().equals(itdi_annotation_introduces)) {
					String v = ann.getStringFormOfValue("value");
					return v.substring(1, v.length() - 1).split(",");
				}
			}
		}
		
		return new String[0];
	}
		
	private static boolean containsAnn(AnnotationAJ[] annotations, String annotationName) {
		if (annotations != null) {
			for (AnnotationAJ ann: annotations) {
				if (ann.getTypeName().equals(annotationName)) {
					return true;
				}
			}
		}
		
		return false;
	}
	
	private static boolean containsAnn(MethodBinding mb, String annotationName) {
		AnnotationBinding[] annotations = mb.getAnnotations();
		if (annotations != null) {
			for (AnnotationBinding ann: annotations) {
				if (new String(CharOperation.concatWith(
						ann.getAnnotationType().compoundName, '.')).equals(annotationName)) {
					return true;
				}
			}
		}
		
		return false;
	}
	
	public static boolean isITDI(ResolvedType interfaceType) {
		return containsAnn(interfaceType.getAnnotations(), itdi_annotation_itdi);
	}
	
	public static boolean isIntroduced(MethodBinding mb) {
		return containsAnn(mb, itdi_annotation_introduced);
	}
	
	public static boolean isFinal(MethodBinding mb) {
		return containsAnn(mb, itdi_annotation_final);
	}
	
	public static MarkerAnnotation createFinalAnnotation(int pos) {
		return createMarkerAnnotation(finalA, pos);
	}
	
	public static SingleMemberAnnotation createIntroducesAnnotation(int pos) {
		return new SingleMemberAnnotation(createQualifiedTypeReference(introduces, pos), pos);
	}
	
	public static MarkerAnnotation createIntroducedAnnotation(int pos) {
		return createMarkerAnnotation(introduced, pos);
	}
	
	public static MarkerAnnotation createITDIAnnotation(int pos) {
		return createMarkerAnnotation(itdiA, pos);
	}
	
	private static MarkerAnnotation createMarkerAnnotation(char[] name, int pos) {
		return new MarkerAnnotation(createQualifiedTypeReference(name, pos), pos);
	}
	
	private static QualifiedTypeReference createQualifiedTypeReference(char[] name, 
			int pos) {
		return new QualifiedTypeReference(new char[][]{itdi, annotation, name},
				new long[]{pos, pos, pos, pos});
	}
	
	private static boolean optionSpecified = false;
	
	public static void resetOption() {
		optionSpecified = false;
	}
	
	public static boolean isOptionSpecified() {
		boolean b = optionSpecified;
		optionSpecified = false;
		return b;
	}
	
	public static void optionSpecified() {
		optionSpecified = true;
	}
}
