/*******************************************************************************
 * Copyright (c) 2000, 2011 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.aspectj.org.eclipse.jdt.internal.compiler.parser;

/**
 * IMPORTANT NOTE: These constants are dedicated to the internal Scanner implementation.
 * It is mirrored in org.aspectj.org.eclipse.jdt.core.compiler public package where it is API.
 * The mirror implementation is using the backward compatible ITerminalSymbols constant
 * definitions (stable with 2.0), whereas the internal implementation uses TerminalTokens
 * which constant values reflect the latest parser generation state.
 */
/**
 * Maps each terminal symbol in the java-grammar into a unique integer.
 * This integer is used to represent the terminal when computing a parsing action.
 *
 * Disclaimer : These constant values are generated automatically using a Java
 * grammar, therefore their actual values are subject to change if new keywords
 * were added to the language (for instance, 'assert' is a keyword in 1.4).
 */
public interface TerminalTokens {

	// special tokens not part of grammar - not autogenerated
	int TokenNameWHITESPACE = 1000,
		TokenNameCOMMENT_LINE = 1001,
		TokenNameCOMMENT_BLOCK = 1002,
		TokenNameCOMMENT_JAVADOC = 1003;

	public final static int
      TokenNameIdentifier = 21,
      TokenNameabstract = 56,
      TokenNameassert = 83,
      TokenNameboolean = 40,
      TokenNamebreak = 84,
      TokenNamebyte = 41,
      TokenNamecase = 108,
      TokenNamecatch = 95,
      TokenNamechar = 42,
      TokenNameclass = 81,
      TokenNamecontinue = 85,
      TokenNameconst = 117,
      TokenNamedefault = 116,
      TokenNamedo = 86,
      TokenNamedouble = 43,
      TokenNameelse = 111,
      TokenNameenum = 112,
      TokenNameextends = 94,
      TokenNamefalse = 65,
      TokenNamefinal = 57,
      TokenNamefinally = 109,
      TokenNamefloat = 44,
      TokenNamefor = 87,
      TokenNamegoto = 118,
      TokenNameif = 88,
      TokenNameimplements = 114,
      TokenNameimport = 96,
      TokenNameinstanceof = 14,
      TokenNameint = 45,
      TokenNameinterface = 110,
      TokenNamelong = 46,
      TokenNamenative = 58,
      TokenNamenew = 51,
      TokenNamenull = 66,
      TokenNamepackage = 93,
      TokenNameprivate = 59,
      TokenNameprotected = 60,
      TokenNamepublic = 61,
      TokenNamereturn = 89,
      TokenNameshort = 47,
      TokenNamestatic = 54,
      TokenNamestrictfp = 62,
      TokenNamesuper = 52,
      TokenNameswitch = 90,
      TokenNamesynchronized = 55,
      TokenNamethis = 53,
      TokenNamethrow = 91,
      TokenNamethrows = 113,
      TokenNametransient = 63,
      TokenNametrue = 67,
      TokenNametry = 92,
      TokenNamevoid = 48,
      TokenNamevolatile = 64,
      TokenNamewhile = 82,
      TokenNameaspect = 30,
      TokenNamepointcut = 32,
      TokenNamearound = 33,
      TokenNamebefore = 34,
      TokenNameafter = 35,
      TokenNamedeclare = 36,
      TokenNameprivileged = 31,
      TokenNameintroduces = 37,
      TokenNameintroduced = 38,
      TokenNameIntegerLiteral = 68,
      TokenNameLongLiteral = 69,
      TokenNameFloatingPointLiteral = 70,
      TokenNameDoubleLiteral = 71,
      TokenNameCharacterLiteral = 72,
      TokenNameStringLiteral = 73,
      TokenNamePLUS_PLUS = 9,
      TokenNameMINUS_MINUS = 10,
      TokenNameEQUAL_EQUAL = 20,
      TokenNameLESS_EQUAL = 15,
      TokenNameGREATER_EQUAL = 16,
      TokenNameNOT_EQUAL = 17,
      TokenNameLEFT_SHIFT = 18,
      TokenNameRIGHT_SHIFT = 11,
      TokenNameUNSIGNED_RIGHT_SHIFT = 13,
      TokenNamePLUS_EQUAL = 97,
      TokenNameMINUS_EQUAL = 98,
      TokenNameMULTIPLY_EQUAL = 99,
      TokenNameDIVIDE_EQUAL = 100,
      TokenNameAND_EQUAL = 101,
      TokenNameOR_EQUAL = 102,
      TokenNameXOR_EQUAL = 103,
      TokenNameREMAINDER_EQUAL = 104,
      TokenNameLEFT_SHIFT_EQUAL = 105,
      TokenNameRIGHT_SHIFT_EQUAL = 106,
      TokenNameUNSIGNED_RIGHT_SHIFT_EQUAL = 107,
      TokenNameOR_OR = 26,
      TokenNameAND_AND = 25,
      TokenNamePLUS = 2,
      TokenNameMINUS = 3,
      TokenNameNOT = 75,
      TokenNameREMAINDER = 7,
      TokenNameXOR = 23,
      TokenNameAND = 19,
      TokenNameMULTIPLY = 5,
      TokenNameOR = 27,
      TokenNameTWIDDLE = 79,
      TokenNameDIVIDE = 8,
      TokenNameGREATER = 12,
      TokenNameLESS = 4,
      TokenNameLPAREN = 22,
      TokenNameRPAREN = 29,
      TokenNameLBRACE = 76,
      TokenNameRBRACE = 49,
      TokenNameLBRACKET = 6,
      TokenNameRBRACKET = 78,
      TokenNameSEMICOLON = 28,
      TokenNameQUESTION = 24,
      TokenNameCOLON = 74,
      TokenNameCOMMA = 39,
      TokenNameDOT = 1,
      TokenNameEQUAL = 80,
      TokenNameAT = 50,
      TokenNameELLIPSIS = 115,
      TokenNameEOF = 77,
      TokenNameERROR = 119;
}
